import type { App } from 'vue';
import { authDirective } from '/@/directive/authDirective';
import {
	dragDirective,
	eleFocusDirective,
	elementResizeDirective,
	focusDirective,
	wavesDirective,
} from '/@/directive/customDirective';
import { inputLimit } from '/@/directive/inputLimit';

/**
 * 导出指令方法：v-xxx
 * @methods authDirective 用户权限指令，用法：v-auth
 * @methods wavesDirective 按钮波浪指令，用法：v-waves
 * @methods dragDirective 自定义拖动指令，用法：v-drag
 * @methods inputLimit 输入限制指令，用法：v-input-limit
 * @methods eleFocusDirective 元素聚焦指令，用法：v-ele-focus
 * @methods elementResizeDirective 元素尺寸变化指令，用法：v-element-resize
 * @methods focusDirective 元素聚焦指令，用法：v-focus
 */
export function directive(app: App) {
	// 用户权限指令
	authDirective(app);
	// 按钮波浪指令
	wavesDirective(app);
	// 自定义拖动指令
	dragDirective(app);
	// 输入限制指令
	inputLimit(app);
	eleFocusDirective(app);
	elementResizeDirective(app);
	focusDirective(app);
}
